import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.SPLRange import SPLRange
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class SoundSensor(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._SPLChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double, ctypes.c_double, ctypes.c_double, ctypes.POINTER(ctypes.c_double))
		else:
			self._SPLChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double, ctypes.c_double, ctypes.c_double, ctypes.POINTER(ctypes.c_double))
		self._SPLChange = None
		self._onSPLChange = None

		__func = PhidgetSupport.getDll().PhidgetSoundSensor_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localSPLChangeEvent(self, handle, userPtr, dB, dBA, dBC, Octaves):
		if self._SPLChange == None:
			return
		Octaves = [Octaves[i] for i in range(10)]
		self._SPLChange(self, dB, dBA, dBC, Octaves)

	def setOnSPLChangeHandler(self, handler):
		if handler == None:
			self._SPLChange = None
			self._onSPLChange = None
		else:
			self._SPLChange = handler
			self._onSPLChange = self._SPLChangeFactory(self._localSPLChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetSoundSensor_setOnSPLChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onSPLChange, None)
		except RuntimeError:
			self._SPLChange = None
			self._onSPLChange = None

	def getDataInterval(self):
		_DataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetSoundSensor_getDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _DataInterval.value

	def setDataInterval(self, DataInterval):
		_DataInterval = ctypes.c_uint32(DataInterval)

		__func = PhidgetSupport.getDll().PhidgetSoundSensor_setDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataInterval)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataInterval(self):
		_MinDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetSoundSensor_getMinDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataInterval.value

	def getMaxDataInterval(self):
		_MaxDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetSoundSensor_getMaxDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataInterval.value

	def getdB(self):
		_dB = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetSoundSensor_getdB
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_dB))

		if result > 0:
			raise PhidgetException(result)

		return _dB.value

	def getMaxdB(self):
		_MaxdB = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetSoundSensor_getMaxdB
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxdB))

		if result > 0:
			raise PhidgetException(result)

		return _MaxdB.value

	def getdBA(self):
		_dBA = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetSoundSensor_getdBA
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_dBA))

		if result > 0:
			raise PhidgetException(result)

		return _dBA.value

	def getdBC(self):
		_dBC = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetSoundSensor_getdBC
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_dBC))

		if result > 0:
			raise PhidgetException(result)

		return _dBC.value

	def getNoiseFloor(self):
		_NoiseFloor = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetSoundSensor_getNoiseFloor
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_NoiseFloor))

		if result > 0:
			raise PhidgetException(result)

		return _NoiseFloor.value

	def getOctaves(self):
		_Octaves = (ctypes.c_double * 10)()

		__func = PhidgetSupport.getDll().PhidgetSoundSensor_getOctaves
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Octaves))

		if result > 0:
			raise PhidgetException(result)

		return list(_Octaves)

	def getSPLChangeTrigger(self):
		_SPLChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetSoundSensor_getSPLChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_SPLChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _SPLChangeTrigger.value

	def setSPLChangeTrigger(self, SPLChangeTrigger):
		_SPLChangeTrigger = ctypes.c_double(SPLChangeTrigger)

		__func = PhidgetSupport.getDll().PhidgetSoundSensor_setSPLChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _SPLChangeTrigger)

		if result > 0:
			raise PhidgetException(result)


	def getMinSPLChangeTrigger(self):
		_MinSPLChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetSoundSensor_getMinSPLChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinSPLChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MinSPLChangeTrigger.value

	def getMaxSPLChangeTrigger(self):
		_MaxSPLChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetSoundSensor_getMaxSPLChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxSPLChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MaxSPLChangeTrigger.value

	def getSPLRange(self):
		_SPLRange = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetSoundSensor_getSPLRange
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_SPLRange))

		if result > 0:
			raise PhidgetException(result)

		return _SPLRange.value

	def setSPLRange(self, SPLRange):
		_SPLRange = ctypes.c_int(SPLRange)

		__func = PhidgetSupport.getDll().PhidgetSoundSensor_setSPLRange
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _SPLRange)

		if result > 0:
			raise PhidgetException(result)




import sys
import ctypes
class RCServoVoltage:
	# Run all servos on 5V DC
	RCSERVO_VOLTAGE_5V = 1
	# Run all servos on 6V DC
	RCSERVO_VOLTAGE_6V = 2
	# Run all servos on 7.4V DC
	RCSERVO_VOLTAGE_7_4V = 3

	@classmethod
	def getName(self, val):
		if val == self.RCSERVO_VOLTAGE_5V:
			return "RCSERVO_VOLTAGE_5V"
		if val == self.RCSERVO_VOLTAGE_6V:
			return "RCSERVO_VOLTAGE_6V"
		if val == self.RCSERVO_VOLTAGE_7_4V:
			return "RCSERVO_VOLTAGE_7_4V"
		return "<invalid enumeration value>"



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.VoltageOutputRange import VoltageOutputRange
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class VoltageOutput(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()
		self._setVoltage_async = None
		self._onsetVoltage_async = None

		__func = PhidgetSupport.getDll().PhidgetVoltageOutput_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def setEnabled(self, Enabled):
		_Enabled = ctypes.c_int(Enabled)

		__func = PhidgetSupport.getDll().PhidgetVoltageOutput_setEnabled
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Enabled)

		if result > 0:
			raise PhidgetException(result)


	def getEnabled(self):
		_Enabled = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetVoltageOutput_getEnabled
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Enabled))

		if result > 0:
			raise PhidgetException(result)

		return _Enabled.value

	def enableFailsafe(self, failsafeTime):
		_failsafeTime = ctypes.c_uint32(failsafeTime)

		__func = PhidgetSupport.getDll().PhidgetVoltageOutput_enableFailsafe
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _failsafeTime)

		if result > 0:
			raise PhidgetException(result)


	def getMinFailsafeTime(self):
		_MinFailsafeTime = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetVoltageOutput_getMinFailsafeTime
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinFailsafeTime))

		if result > 0:
			raise PhidgetException(result)

		return _MinFailsafeTime.value

	def getMaxFailsafeTime(self):
		_MaxFailsafeTime = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetVoltageOutput_getMaxFailsafeTime
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxFailsafeTime))

		if result > 0:
			raise PhidgetException(result)

		return _MaxFailsafeTime.value

	def resetFailsafe(self):
		__func = PhidgetSupport.getDll().PhidgetVoltageOutput_resetFailsafe
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)


	def getVoltage(self):
		_Voltage = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetVoltageOutput_getVoltage
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Voltage))

		if result > 0:
			raise PhidgetException(result)

		return _Voltage.value

	def setVoltage(self, Voltage):
		_Voltage = ctypes.c_double(Voltage)

		__func = PhidgetSupport.getDll().PhidgetVoltageOutput_setVoltage
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Voltage)

		if result > 0:
			raise PhidgetException(result)


	def getMinVoltage(self):
		_MinVoltage = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetVoltageOutput_getMinVoltage
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinVoltage))

		if result > 0:
			raise PhidgetException(result)

		return _MinVoltage.value

	def getMaxVoltage(self):
		_MaxVoltage = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetVoltageOutput_getMaxVoltage
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxVoltage))

		if result > 0:
			raise PhidgetException(result)

		return _MaxVoltage.value

	def setVoltage_async(self, Voltage, asyncHandler):
		_Voltage = ctypes.c_double(Voltage)

		_ctx = ctypes.c_void_p()
		if asyncHandler != None:
			_ctx = ctypes.c_void_p(AsyncSupport.add(asyncHandler, self))
		_asyncHandler = AsyncSupport.getCallback()

		__func = PhidgetSupport.getDll().PhidgetVoltageOutput_setVoltage_async
		__func(self.handle, _Voltage, _asyncHandler, _ctx)


	def getVoltageOutputRange(self):
		_VoltageOutputRange = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetVoltageOutput_getVoltageOutputRange
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_VoltageOutputRange))

		if result > 0:
			raise PhidgetException(result)

		return _VoltageOutputRange.value

	def setVoltageOutputRange(self, VoltageOutputRange):
		_VoltageOutputRange = ctypes.c_int(VoltageOutputRange)

		__func = PhidgetSupport.getDll().PhidgetVoltageOutput_setVoltageOutputRange
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _VoltageOutputRange)

		if result > 0:
			raise PhidgetException(result)




import sys
import ctypes
class VoltageRatioSensorType:
	# Default. Configures the channel to be a generic ratiometric sensor. Unit is volts/volt.
	SENSOR_TYPE_VOLTAGERATIO = 0
	# 1101 - IR Distance Adapter, with Sharp Distance Sensor 2D120X (4-30cm)
	SENSOR_TYPE_1101_SHARP_2D120X = 11011
	# 1101 - IR Distance Adapter, with Sharp Distance Sensor 2Y0A21 (10-80cm)
	SENSOR_TYPE_1101_SHARP_2Y0A21 = 11012
	# 1101 - IR Distance Adapter, with Sharp Distance Sensor 2Y0A02 (20-150cm)
	SENSOR_TYPE_1101_SHARP_2Y0A02 = 11013
	# 1102 - IR Reflective Sensor 5mm
	SENSOR_TYPE_1102 = 11020
	# 1103 - IR Reflective Sensor 10cm
	SENSOR_TYPE_1103 = 11030
	# 1104 - Vibration Sensor
	SENSOR_TYPE_1104 = 11040
	# 1105 - Light Sensor
	SENSOR_TYPE_1105 = 11050
	# 1106 - Force Sensor
	SENSOR_TYPE_1106 = 11060
	# 1107 - Humidity Sensor
	SENSOR_TYPE_1107 = 11070
	# 1108 - Magnetic Sensor
	SENSOR_TYPE_1108 = 11080
	# 1109 - Rotation Sensor
	SENSOR_TYPE_1109 = 11090
	# 1110 - Touch Sensor
	SENSOR_TYPE_1110 = 11100
	# 1111 - Motion Sensor
	SENSOR_TYPE_1111 = 11110
	# 1112 - Slider 60
	SENSOR_TYPE_1112 = 11120
	# 1113 - Mini Joy Stick Sensor
	SENSOR_TYPE_1113 = 11130
	# 1115 - Pressure Sensor
	SENSOR_TYPE_1115 = 11150
	# 1116 - Multi-turn Rotation Sensor
	SENSOR_TYPE_1116 = 11160
	# 1118 - 50Amp Current Sensor AC
	SENSOR_TYPE_1118_AC = 11181
	# 1118 - 50Amp Current Sensor DC
	SENSOR_TYPE_1118_DC = 11182
	# 1119 - 20Amp Current Sensor AC
	SENSOR_TYPE_1119_AC = 11191
	# 1119 - 20Amp Current Sensor DC
	SENSOR_TYPE_1119_DC = 11192
	# 1120 - FlexiForce Adapter
	SENSOR_TYPE_1120 = 11200
	# 1121 - Voltage Divider
	SENSOR_TYPE_1121 = 11210
	# 1122 - 30 Amp Current Sensor AC
	SENSOR_TYPE_1122_AC = 11221
	# 1122 - 30 Amp Current Sensor DC
	SENSOR_TYPE_1122_DC = 11222
	# 1124 - Precision Temperature Sensor
	SENSOR_TYPE_1124 = 11240
	# 1125 - Humidity Sensor
	SENSOR_TYPE_1125_HUMIDITY = 11251
	# 1125 - Temperature Sensor
	SENSOR_TYPE_1125_TEMPERATURE = 11252
	# 1126 - Differential Air Pressure Sensor +- 25kPa
	SENSOR_TYPE_1126 = 11260
	# 1128 - MaxBotix EZ-1 Sonar Sensor
	SENSOR_TYPE_1128 = 11280
	# 1129 - Touch Sensor
	SENSOR_TYPE_1129 = 11290
	# 1131 - Thin Force Sensor
	SENSOR_TYPE_1131 = 11310
	# 1134 - Switchable Voltage Divider
	SENSOR_TYPE_1134 = 11340
	# 1136 - Differential Air Pressure Sensor +-2 kPa
	SENSOR_TYPE_1136 = 11360
	# 1137 - Differential Air Pressure Sensor +-7 kPa
	SENSOR_TYPE_1137 = 11370
	# 1138 - Differential Air Pressure Sensor 50 kPa
	SENSOR_TYPE_1138 = 11380
	# 1139 - Differential Air Pressure Sensor 100 kPa
	SENSOR_TYPE_1139 = 11390
	# 1140 - Absolute Air Pressure Sensor 20-400 kPa
	SENSOR_TYPE_1140 = 11400
	# 1141 - Absolute Air Pressure Sensor 15-115 kPa
	SENSOR_TYPE_1141 = 11410
	# 1146 - IR Reflective Sensor 1-4mm
	SENSOR_TYPE_1146 = 11460
	# 3120 - Compression Load Cell (0-4.5 kg)
	SENSOR_TYPE_3120 = 31200
	# 3121 - Compression Load Cell (0-11.3 kg)
	SENSOR_TYPE_3121 = 31210
	# 3122 - Compression Load Cell (0-22.7 kg)
	SENSOR_TYPE_3122 = 31220
	# 3123 - Compression Load Cell (0-45.3 kg)
	SENSOR_TYPE_3123 = 31230
	# 3130 - Relative Humidity Sensor
	SENSOR_TYPE_3130 = 31300
	# 3520 - Sharp Distance Sensor (4-30cm)
	SENSOR_TYPE_3520 = 35200
	# 3521 - Sharp Distance Sensor (10-80cm)
	SENSOR_TYPE_3521 = 35210
	# 3522 - Sharp Distance Sensor (20-150cm)
	SENSOR_TYPE_3522 = 35220

	@classmethod
	def getName(self, val):
		if val == self.SENSOR_TYPE_VOLTAGERATIO:
			return "SENSOR_TYPE_VOLTAGERATIO"
		if val == self.SENSOR_TYPE_1101_SHARP_2D120X:
			return "SENSOR_TYPE_1101_SHARP_2D120X"
		if val == self.SENSOR_TYPE_1101_SHARP_2Y0A21:
			return "SENSOR_TYPE_1101_SHARP_2Y0A21"
		if val == self.SENSOR_TYPE_1101_SHARP_2Y0A02:
			return "SENSOR_TYPE_1101_SHARP_2Y0A02"
		if val == self.SENSOR_TYPE_1102:
			return "SENSOR_TYPE_1102"
		if val == self.SENSOR_TYPE_1103:
			return "SENSOR_TYPE_1103"
		if val == self.SENSOR_TYPE_1104:
			return "SENSOR_TYPE_1104"
		if val == self.SENSOR_TYPE_1105:
			return "SENSOR_TYPE_1105"
		if val == self.SENSOR_TYPE_1106:
			return "SENSOR_TYPE_1106"
		if val == self.SENSOR_TYPE_1107:
			return "SENSOR_TYPE_1107"
		if val == self.SENSOR_TYPE_1108:
			return "SENSOR_TYPE_1108"
		if val == self.SENSOR_TYPE_1109:
			return "SENSOR_TYPE_1109"
		if val == self.SENSOR_TYPE_1110:
			return "SENSOR_TYPE_1110"
		if val == self.SENSOR_TYPE_1111:
			return "SENSOR_TYPE_1111"
		if val == self.SENSOR_TYPE_1112:
			return "SENSOR_TYPE_1112"
		if val == self.SENSOR_TYPE_1113:
			return "SENSOR_TYPE_1113"
		if val == self.SENSOR_TYPE_1115:
			return "SENSOR_TYPE_1115"
		if val == self.SENSOR_TYPE_1116:
			return "SENSOR_TYPE_1116"
		if val == self.SENSOR_TYPE_1118_AC:
			return "SENSOR_TYPE_1118_AC"
		if val == self.SENSOR_TYPE_1118_DC:
			return "SENSOR_TYPE_1118_DC"
		if val == self.SENSOR_TYPE_1119_AC:
			return "SENSOR_TYPE_1119_AC"
		if val == self.SENSOR_TYPE_1119_DC:
			return "SENSOR_TYPE_1119_DC"
		if val == self.SENSOR_TYPE_1120:
			return "SENSOR_TYPE_1120"
		if val == self.SENSOR_TYPE_1121:
			return "SENSOR_TYPE_1121"
		if val == self.SENSOR_TYPE_1122_AC:
			return "SENSOR_TYPE_1122_AC"
		if val == self.SENSOR_TYPE_1122_DC:
			return "SENSOR_TYPE_1122_DC"
		if val == self.SENSOR_TYPE_1124:
			return "SENSOR_TYPE_1124"
		if val == self.SENSOR_TYPE_1125_HUMIDITY:
			return "SENSOR_TYPE_1125_HUMIDITY"
		if val == self.SENSOR_TYPE_1125_TEMPERATURE:
			return "SENSOR_TYPE_1125_TEMPERATURE"
		if val == self.SENSOR_TYPE_1126:
			return "SENSOR_TYPE_1126"
		if val == self.SENSOR_TYPE_1128:
			return "SENSOR_TYPE_1128"
		if val == self.SENSOR_TYPE_1129:
			return "SENSOR_TYPE_1129"
		if val == self.SENSOR_TYPE_1131:
			return "SENSOR_TYPE_1131"
		if val == self.SENSOR_TYPE_1134:
			return "SENSOR_TYPE_1134"
		if val == self.SENSOR_TYPE_1136:
			return "SENSOR_TYPE_1136"
		if val == self.SENSOR_TYPE_1137:
			return "SENSOR_TYPE_1137"
		if val == self.SENSOR_TYPE_1138:
			return "SENSOR_TYPE_1138"
		if val == self.SENSOR_TYPE_1139:
			return "SENSOR_TYPE_1139"
		if val == self.SENSOR_TYPE_1140:
			return "SENSOR_TYPE_1140"
		if val == self.SENSOR_TYPE_1141:
			return "SENSOR_TYPE_1141"
		if val == self.SENSOR_TYPE_1146:
			return "SENSOR_TYPE_1146"
		if val == self.SENSOR_TYPE_3120:
			return "SENSOR_TYPE_3120"
		if val == self.SENSOR_TYPE_3121:
			return "SENSOR_TYPE_3121"
		if val == self.SENSOR_TYPE_3122:
			return "SENSOR_TYPE_3122"
		if val == self.SENSOR_TYPE_3123:
			return "SENSOR_TYPE_3123"
		if val == self.SENSOR_TYPE_3130:
			return "SENSOR_TYPE_3130"
		if val == self.SENSOR_TYPE_3520:
			return "SENSOR_TYPE_3520"
		if val == self.SENSOR_TYPE_3521:
			return "SENSOR_TYPE_3521"
		if val == self.SENSOR_TYPE_3522:
			return "SENSOR_TYPE_3522"
		return "<invalid enumeration value>"



import sys
import ctypes
class ChannelSubclass:
	# No subclass
	PHIDCHSUBCLASS_NONE = 1
	# Digital output duty cycle
	PHIDCHSUBCLASS_DIGITALOUTPUT_DUTY_CYCLE = 16
	# Digital output LED driver
	PHIDCHSUBCLASS_DIGITALOUTPUT_LED_DRIVER = 17
	# Digital output frequency
	PHIDCHSUBCLASS_DIGITALOUTPUT_FREQUENCY = 18
	# Temperature sensor RTD
	PHIDCHSUBCLASS_TEMPERATURESENSOR_RTD = 32
	# Temperature sensor thermocouple
	PHIDCHSUBCLASS_TEMPERATURESENSOR_THERMOCOUPLE = 33
	# Voltage sensor port
	PHIDCHSUBCLASS_VOLTAGEINPUT_SENSOR_PORT = 48
	# Voltage ratio sensor port
	PHIDCHSUBCLASS_VOLTAGERATIOINPUT_SENSOR_PORT = 64
	# Voltage ratio bridge input
	PHIDCHSUBCLASS_VOLTAGERATIOINPUT_BRIDGE = 65
	# Graphic LCD
	PHIDCHSUBCLASS_LCD_GRAPHIC = 80
	# Text LCD
	PHIDCHSUBCLASS_LCD_TEXT = 81
	# Encoder IO mode settable
	PHIDCHSUBCLASS_ENCODER_MODE_SETTABLE = 96
	# Spatial AHRS/IMU
	PHIDCHSUBCLASS_SPATIAL_AHRS = 112

	@classmethod
	def getName(self, val):
		if val == self.PHIDCHSUBCLASS_NONE:
			return "PHIDCHSUBCLASS_NONE"
		if val == self.PHIDCHSUBCLASS_DIGITALOUTPUT_DUTY_CYCLE:
			return "PHIDCHSUBCLASS_DIGITALOUTPUT_DUTY_CYCLE"
		if val == self.PHIDCHSUBCLASS_DIGITALOUTPUT_LED_DRIVER:
			return "PHIDCHSUBCLASS_DIGITALOUTPUT_LED_DRIVER"
		if val == self.PHIDCHSUBCLASS_DIGITALOUTPUT_FREQUENCY:
			return "PHIDCHSUBCLASS_DIGITALOUTPUT_FREQUENCY"
		if val == self.PHIDCHSUBCLASS_TEMPERATURESENSOR_RTD:
			return "PHIDCHSUBCLASS_TEMPERATURESENSOR_RTD"
		if val == self.PHIDCHSUBCLASS_TEMPERATURESENSOR_THERMOCOUPLE:
			return "PHIDCHSUBCLASS_TEMPERATURESENSOR_THERMOCOUPLE"
		if val == self.PHIDCHSUBCLASS_VOLTAGEINPUT_SENSOR_PORT:
			return "PHIDCHSUBCLASS_VOLTAGEINPUT_SENSOR_PORT"
		if val == self.PHIDCHSUBCLASS_VOLTAGERATIOINPUT_SENSOR_PORT:
			return "PHIDCHSUBCLASS_VOLTAGERATIOINPUT_SENSOR_PORT"
		if val == self.PHIDCHSUBCLASS_VOLTAGERATIOINPUT_BRIDGE:
			return "PHIDCHSUBCLASS_VOLTAGERATIOINPUT_BRIDGE"
		if val == self.PHIDCHSUBCLASS_LCD_GRAPHIC:
			return "PHIDCHSUBCLASS_LCD_GRAPHIC"
		if val == self.PHIDCHSUBCLASS_LCD_TEXT:
			return "PHIDCHSUBCLASS_LCD_TEXT"
		if val == self.PHIDCHSUBCLASS_ENCODER_MODE_SETTABLE:
			return "PHIDCHSUBCLASS_ENCODER_MODE_SETTABLE"
		if val == self.PHIDCHSUBCLASS_SPATIAL_AHRS:
			return "PHIDCHSUBCLASS_SPATIAL_AHRS"
		return "<invalid enumeration value>"



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class Manager:

	def __init__(self):
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._AttachFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_void_p)
		else:
			self._AttachFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_void_p)
		self._Attach = None
		self._onAttach = None

		if sys.platform == 'win32':
			self._DetachFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_void_p)
		else:
			self._DetachFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_void_p)
		self._Detach = None
		self._onDetach = None

		__func = PhidgetSupport.getDll().PhidgetManager_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		__func = PhidgetSupport.getDll().PhidgetManager_delete
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))
		self.handle = None
		if res > 0:
			raise PhidgetException(res)

	def _localAttachEvent(self, handle, userPtr, Channel):
		if self._Attach == None:
			return
		__func = PhidgetSupport.getDll().Phidget_retain
		__func.restype = ctypes.c_int32
		result = __func(ctypes.c_void_p(Channel))
		if result > 0:
			raise PhidgetException(result)
		ph = Phidget()
		ph.handle = ctypes.c_void_p(Channel)
		self._Attach(self, ph)

	def setOnAttachHandler(self, handler):
		if handler == None:
			self._Attach = None
			self._onAttach = None
		else:
			self._Attach = handler
			self._onAttach = self._AttachFactory(self._localAttachEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetManager_setOnAttachHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onAttach, None)
		except RuntimeError:
			self._Attach = None
			self._onAttach = None

	def _localDetachEvent(self, handle, userPtr, Channel):
		if self._Detach == None:
			return
		__func = PhidgetSupport.getDll().Phidget_retain
		__func.restype = ctypes.c_int32
		result = __func(ctypes.c_void_p(Channel))
		if result > 0:
			raise PhidgetException(result)
		ph = Phidget()
		ph.handle = ctypes.c_void_p(Channel)
		self._Detach(self, ph)

	def setOnDetachHandler(self, handler):
		if handler == None:
			self._Detach = None
			self._onDetach = None
		else:
			self._Detach = handler
			self._onDetach = self._DetachFactory(self._localDetachEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetManager_setOnDetachHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onDetach, None)
		except RuntimeError:
			self._Detach = None
			self._onDetach = None

	def close(self):
		__func = PhidgetSupport.getDll().PhidgetManager_close
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)


	def open(self):
		__func = PhidgetSupport.getDll().PhidgetManager_open
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)




import sys
import ctypes

from Phidget22.IRCodeEncoding import IRCodeEncoding
from Phidget22.IRCodeLength import IRCodeLength

class CodeInfo(ctypes.Structure):
	_fields_ = [
		("_bitCount", ctypes.c_uint32),
		("_encoding", ctypes.c_int),
		("_length", ctypes.c_int),
		("_gap", ctypes.c_uint32),
		("_trail", ctypes.c_uint32),
		("_header", ctypes.c_uint32 * 2),
		("_one", ctypes.c_uint32 * 2),
		("_zero", ctypes.c_uint32 * 2),
		("_repeat", ctypes.c_uint32 * 26),
		("_minRepeat", ctypes.c_uint32),
		("_dutyCycle", ctypes.c_double),
		("_carrierFrequency", ctypes.c_uint32),
		("_toggleMask", ctypes.c_char * 33),
	]

	def __init__(self):
		self.bitCount = 0
		self.encoding = 0
		self.length = 0
		self.gap = 0
		self.trail = 0
		self.header = [0] * 2
		self.one = [0] * 2
		self.zero = [0] * 2
		self.repeat = [0] * 26
		self.minRepeat = 0
		self.dutyCycle = 0
		self.carrierFrequency = 0
		self.toggleMask = ""

	def fromPython(self):
		self._bitCount = self.bitCount
		self._encoding = self.encoding
		self._length = self.length
		self._gap = self.gap
		self._trail = self.trail
		self._header = (ctypes.c_uint32 * 2)(*self.header)
		self._one = (ctypes.c_uint32 * 2)(*self.one)
		self._zero = (ctypes.c_uint32 * 2)(*self.zero)
		self._repeat = (ctypes.c_uint32 * 26)(*self.repeat)
		self._minRepeat = self.minRepeat
		self._dutyCycle = self.dutyCycle
		self._carrierFrequency = self.carrierFrequency
		self._toggleMask = self.toggleMask.encode('utf-8')
		return self

	def toPython(self):
		if self._bitCount == None:
			self.bitCount = None
		else:
			self.bitCount = self._bitCount
		if self._encoding == None:
			self.encoding = None
		else:
			self.encoding = self._encoding
		if self._length == None:
			self.length = None
		else:
			self.length = self._length
		if self._gap == None:
			self.gap = None
		else:
			self.gap = self._gap
		if self._trail == None:
			self.trail = None
		else:
			self.trail = self._trail
		if self._header == None:
			self.header = None
		else:
			self.header = self._header
		if self._one == None:
			self.one = None
		else:
			self.one = self._one
		if self._zero == None:
			self.zero = None
		else:
			self.zero = self._zero
		if self._repeat == None:
			self.repeat = None
		else:
			self.repeat = self._repeat
		if self._minRepeat == None:
			self.minRepeat = None
		else:
			self.minRepeat = self._minRepeat
		if self._dutyCycle == None:
			self.dutyCycle = None
		else:
			self.dutyCycle = self._dutyCycle
		if self._carrierFrequency == None:
			self.carrierFrequency = None
		else:
			self.carrierFrequency = self._carrierFrequency
		if self._toggleMask == None:
			self.toggleMask = None
		else:
			self.toggleMask = self._toggleMask.decode('utf-8')
		return self

	def __str__(self):
		return ("[CodeInfo] ("
			"bitCount: " + str(self.bitCount) + ", "
			"encoding: " + str(self.encoding) + ", "
			"length: " + str(self.length) + ", "
			"gap: " + str(self.gap) + ", "
			"trail: " + str(self.trail) + ", "
			"header: " + str(self.header) + ", "
			"one: " + str(self.one) + ", "
			"zero: " + str(self.zero) + ", "
			"repeat: " + str(self.repeat) + ", "
			"minRepeat: " + str(self.minRepeat) + ", "
			"dutyCycle: " + str(self.dutyCycle) + ", "
			"carrierFrequency: " + str(self.carrierFrequency) + ", "
			"toggleMask: " + str(self.toggleMask) + 
			")")



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class LightSensor(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._IlluminanceChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		else:
			self._IlluminanceChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		self._IlluminanceChange = None
		self._onIlluminanceChange = None

		__func = PhidgetSupport.getDll().PhidgetLightSensor_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localIlluminanceChangeEvent(self, handle, userPtr, illuminance):
		if self._IlluminanceChange == None:
			return
		self._IlluminanceChange(self, illuminance)

	def setOnIlluminanceChangeHandler(self, handler):
		if handler == None:
			self._IlluminanceChange = None
			self._onIlluminanceChange = None
		else:
			self._IlluminanceChange = handler
			self._onIlluminanceChange = self._IlluminanceChangeFactory(self._localIlluminanceChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetLightSensor_setOnIlluminanceChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onIlluminanceChange, None)
		except RuntimeError:
			self._IlluminanceChange = None
			self._onIlluminanceChange = None

	def getDataInterval(self):
		_DataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetLightSensor_getDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _DataInterval.value

	def setDataInterval(self, DataInterval):
		_DataInterval = ctypes.c_uint32(DataInterval)

		__func = PhidgetSupport.getDll().PhidgetLightSensor_setDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataInterval)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataInterval(self):
		_MinDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetLightSensor_getMinDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataInterval.value

	def getMaxDataInterval(self):
		_MaxDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetLightSensor_getMaxDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataInterval.value

	def getIlluminance(self):
		_Illuminance = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetLightSensor_getIlluminance
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Illuminance))

		if result > 0:
			raise PhidgetException(result)

		return _Illuminance.value

	def getMinIlluminance(self):
		_MinIlluminance = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetLightSensor_getMinIlluminance
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinIlluminance))

		if result > 0:
			raise PhidgetException(result)

		return _MinIlluminance.value

	def getMaxIlluminance(self):
		_MaxIlluminance = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetLightSensor_getMaxIlluminance
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxIlluminance))

		if result > 0:
			raise PhidgetException(result)

		return _MaxIlluminance.value

	def getIlluminanceChangeTrigger(self):
		_IlluminanceChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetLightSensor_getIlluminanceChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_IlluminanceChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _IlluminanceChangeTrigger.value

	def setIlluminanceChangeTrigger(self, IlluminanceChangeTrigger):
		_IlluminanceChangeTrigger = ctypes.c_double(IlluminanceChangeTrigger)

		__func = PhidgetSupport.getDll().PhidgetLightSensor_setIlluminanceChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _IlluminanceChangeTrigger)

		if result > 0:
			raise PhidgetException(result)


	def getMinIlluminanceChangeTrigger(self):
		_MinIlluminanceChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetLightSensor_getMinIlluminanceChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinIlluminanceChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MinIlluminanceChangeTrigger.value

	def getMaxIlluminanceChangeTrigger(self):
		_MaxIlluminanceChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetLightSensor_getMaxIlluminanceChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxIlluminanceChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MaxIlluminanceChangeTrigger.value



import sys
import ctypes


class GPSDate(ctypes.Structure):
	_fields_ = [
		("_tm_mday", ctypes.c_int16),
		("_tm_mon", ctypes.c_int16),
		("_tm_year", ctypes.c_int16),
	]

	def __init__(self):
		self.tm_mday = 0
		self.tm_mon = 0
		self.tm_year = 0

	def fromPython(self):
		self._tm_mday = self.tm_mday
		self._tm_mon = self.tm_mon
		self._tm_year = self.tm_year
		return self

	def toPython(self):
		if self._tm_mday == None:
			self.tm_mday = None
		else:
			self.tm_mday = self._tm_mday
		if self._tm_mon == None:
			self.tm_mon = None
		else:
			self.tm_mon = self._tm_mon
		if self._tm_year == None:
			self.tm_year = None
		else:
			self.tm_year = self._tm_year
		return self

	def __str__(self):
		return ("[GPSDate] ("
			"tm_mday: " + str(self.tm_mday) + ", "
			"tm_mon: " + str(self.tm_mon) + ", "
			"tm_year: " + str(self.tm_year) + 
			")")



import sys
import ctypes
class ThermocoupleType:
	# Configures the thermocouple input as a J-Type thermocouple.
	THERMOCOUPLE_TYPE_J = 1
	# Configures the thermocouple input as a K-Type thermocouple.
	THERMOCOUPLE_TYPE_K = 2
	# Configures the thermocouple input as a E-Type thermocouple.
	THERMOCOUPLE_TYPE_E = 3
	# Configures the thermocouple input as a T-Type thermocouple.
	THERMOCOUPLE_TYPE_T = 4

	@classmethod
	def getName(self, val):
		if val == self.THERMOCOUPLE_TYPE_J:
			return "THERMOCOUPLE_TYPE_J"
		if val == self.THERMOCOUPLE_TYPE_K:
			return "THERMOCOUPLE_TYPE_K"
		if val == self.THERMOCOUPLE_TYPE_E:
			return "THERMOCOUPLE_TYPE_E"
		if val == self.THERMOCOUPLE_TYPE_T:
			return "THERMOCOUPLE_TYPE_T"
		return "<invalid enumeration value>"



import sys
import ctypes
class Endianness:
	# MSB First
	ENDIANNESS_MSB_FIRST = 1
	# LSB First
	ENDIANNESS_LSB_FIRST = 2

	@classmethod
	def getName(self, val):
		if val == self.ENDIANNESS_MSB_FIRST:
			return "ENDIANNESS_MSB_FIRST"
		if val == self.ENDIANNESS_LSB_FIRST:
			return "ENDIANNESS_LSB_FIRST"
		return "<invalid enumeration value>"



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.PowerSupply import PowerSupply
from Phidget22.VoltageSensorType import VoltageSensorType
from Phidget22.UnitInfo import UnitInfo
from Phidget22.Unit import Unit
from Phidget22.VoltageRange import VoltageRange
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class VoltageInput(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._SensorChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double, ctypes.POINTER(UnitInfo))
		else:
			self._SensorChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double, ctypes.POINTER(UnitInfo))
		self._SensorChange = None
		self._onSensorChange = None

		if sys.platform == 'win32':
			self._VoltageChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		else:
			self._VoltageChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		self._VoltageChange = None
		self._onVoltageChange = None

		__func = PhidgetSupport.getDll().PhidgetVoltageInput_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localSensorChangeEvent(self, handle, userPtr, sensorValue, sensorUnit):
		if self._SensorChange == None:
			return
		if sensorUnit != None:
			sensorUnit = sensorUnit.contents
			sensorUnit.toPython()
		self._SensorChange(self, sensorValue, sensorUnit)

	def setOnSensorChangeHandler(self, handler):
		if handler == None:
			self._SensorChange = None
			self._onSensorChange = None
		else:
			self._SensorChange = handler
			self._onSensorChange = self._SensorChangeFactory(self._localSensorChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetVoltageInput_setOnSensorChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onSensorChange, None)
		except RuntimeError:
			self._SensorChange = None
			self._onSensorChange = None

	def _localVoltageChangeEvent(self, handle, userPtr, voltage):
		if self._VoltageChange == None:
			return
		self._VoltageChange(self, voltage)

	def setOnVoltageChangeHandler(self, handler):
		if handler == None:
			self._VoltageChange = None
			self._onVoltageChange = None
		else:
			self._VoltageChange = handler
			self._onVoltageChange = self._VoltageChangeFactory(self._localVoltageChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetVoltageInput_setOnVoltageChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onVoltageChange, None)
		except RuntimeError:
			self._VoltageChange = None
			self._onVoltageChange = None

	def getDataInterval(self):
		_DataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetVoltageInput_getDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _DataInterval.value

	def setDataInterval(self, DataInterval):
		_DataInterval = ctypes.c_uint32(DataInterval)

		__func = PhidgetSupport.getDll().PhidgetVoltageInput_setDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataInterval)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataInterval(self):
		_MinDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetVoltageInput_getMinDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataInterval.value

	def getMaxDataInterval(self):
		_MaxDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetVoltageInput_getMaxDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataInterval.value

	def getPowerSupply(self):
		_PowerSupply = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetVoltageInput_getPowerSupply
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_PowerSupply))

		if result > 0:
			raise PhidgetException(result)

		return _PowerSupply.value

	def setPowerSupply(self, PowerSupply):
		_PowerSupply = ctypes.c_int(PowerSupply)

		__func = PhidgetSupport.getDll().PhidgetVoltageInput_setPowerSupply
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _PowerSupply)

		if result > 0:
			raise PhidgetException(result)


	def getSensorType(self):
		_SensorType = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetVoltageInput_getSensorType
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_SensorType))

		if result > 0:
			raise PhidgetException(result)

		return _SensorType.value

	def setSensorType(self, SensorType):
		_SensorType = ctypes.c_int(SensorType)

		__func = PhidgetSupport.getDll().PhidgetVoltageInput_setSensorType
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _SensorType)

		if result > 0:
			raise PhidgetException(result)


	def getSensorUnit(self):
		_SensorUnit = UnitInfo()

		__func = PhidgetSupport.getDll().PhidgetVoltageInput_getSensorUnit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_SensorUnit))

		if result > 0:
			raise PhidgetException(result)

		return _SensorUnit.toPython()

	def getSensorValue(self):
		_SensorValue = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetVoltageInput_getSensorValue
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_SensorValue))

		if result > 0:
			raise PhidgetException(result)

		return _SensorValue.value

	def getSensorValueChangeTrigger(self):
		_SensorValueChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetVoltageInput_getSensorValueChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_SensorValueChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _SensorValueChangeTrigger.value

	def setSensorValueChangeTrigger(self, SensorValueChangeTrigger):
		_SensorValueChangeTrigger = ctypes.c_double(SensorValueChangeTrigger)

		__func = PhidgetSupport.getDll().PhidgetVoltageInput_setSensorValueChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _SensorValueChangeTrigger)

		if result > 0:
			raise PhidgetException(result)


	def getVoltage(self):
		_Voltage = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetVoltageInput_getVoltage
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Voltage))

		if result > 0:
			raise PhidgetException(result)

		return _Voltage.value

	def getMinVoltage(self):
		_MinVoltage = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetVoltageInput_getMinVoltage
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinVoltage))

		if result > 0:
			raise PhidgetException(result)

		return _MinVoltage.value

	def getMaxVoltage(self):
		_MaxVoltage = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetVoltageInput_getMaxVoltage
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxVoltage))

		if result > 0:
			raise PhidgetException(result)

		return _MaxVoltage.value

	def getVoltageChangeTrigger(self):
		_VoltageChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetVoltageInput_getVoltageChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_VoltageChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _VoltageChangeTrigger.value

	def setVoltageChangeTrigger(self, VoltageChangeTrigger):
		_VoltageChangeTrigger = ctypes.c_double(VoltageChangeTrigger)

		__func = PhidgetSupport.getDll().PhidgetVoltageInput_setVoltageChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _VoltageChangeTrigger)

		if result > 0:
			raise PhidgetException(result)


	def getMinVoltageChangeTrigger(self):
		_MinVoltageChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetVoltageInput_getMinVoltageChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinVoltageChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MinVoltageChangeTrigger.value

	def getMaxVoltageChangeTrigger(self):
		_MaxVoltageChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetVoltageInput_getMaxVoltageChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxVoltageChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MaxVoltageChangeTrigger.value

	def getVoltageRange(self):
		_VoltageRange = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetVoltageInput_getVoltageRange
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_VoltageRange))

		if result > 0:
			raise PhidgetException(result)

		return _VoltageRange.value

	def setVoltageRange(self, VoltageRange):
		_VoltageRange = ctypes.c_int(VoltageRange)

		__func = PhidgetSupport.getDll().PhidgetVoltageInput_setVoltageRange
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _VoltageRange)

		if result > 0:
			raise PhidgetException(result)




import sys
import ctypes
class ErrorCode:
	# Call succeeded.
	EPHIDGET_OK = 0
	# Not Permitted
	EPHIDGET_PERM = 1
	# The specified entity does not exist. This is usually a result of Net or Log API calls.
	EPHIDGET_NOENT = 2
	# Call has timed out. This can happen for a number of common reasons: Check that the Phidget you are trying to open is plugged in, and that the addressing parameters have been specified correctly. Check that the Phidget is not already open in another program, such as the Phidget Control Panel, or another program you are developing. If your Phidget has a plug or terminal block for external power, ensure it is plugged in and powered. If you are using remote Phidgets, ensure that your computer can access the remote Phidgets using the Phidget Control Panel. If you are using remote Phidgets, ensure you have enabled Server Discovery or added the server corresponding to the Phidget you are trying to open. If you are using Network Server Discovery, try extending the timeout to allow more time for the server to be discovered.
	EPHIDGET_TIMEOUT = 3
	# Keep Alive Failure
	EPHIDGET_KEEPALIVE = 58
	# The operation was interrupted; either from an error, or because the device was closed.
	EPHIDGET_INTERRUPTED = 4
	# IO Issue
	EPHIDGET_IO = 5
	# Memory Issue
	EPHIDGET_NOMEMORY = 6
	# Access to the resource (file) is denied. This can happen when enabling logging.
	EPHIDGET_ACCESS = 7
	# Address Issue
	EPHIDGET_FAULT = 8
	# Specified resource is in use. This error code is not normally used.
	EPHIDGET_BUSY = 9
	# Object Exists
	EPHIDGET_EXIST = 10
	# Object is not a directory
	EPHIDGET_NOTDIR = 11
	# Object is a directory
	EPHIDGET_ISDIR = 12
	# Invalid or malformed command. This can be caused by sending a command to a device which is not supported in it's current configuration.
	EPHIDGET_INVALID = 13
	# Too many open files in system
	EPHIDGET_NFILE = 14
	# Too many open files
	EPHIDGET_MFILE = 15
	# The provided buffer argument size is too small.
	EPHIDGET_NOSPC = 16
	# File too Big
	EPHIDGET_FBIG = 17
	# Read Only Filesystem
	EPHIDGET_ROFS = 18
	# Read Only Object
	EPHIDGET_RO = 19
	# This API call is not supported. For Class APIs this means that this API is not supported by this device. This can also mean the API is not supported on this OS, or OS configuration.
	EPHIDGET_UNSUPPORTED = 20
	# One or more of the parameters passed to the function is not accepted by the channel in its current configuration.
	EPHIDGET_INVALIDARG = 21
	# Try again
	EPHIDGET_AGAIN = 22
	# Not Empty
	EPHIDGET_NOTEMPTY = 26
	# Something unexpected has occured. Enable library logging and have a look at the log, or contact Phidgets support.
	EPHIDGET_UNEXPECTED = 28
	# Duplicated request. Can happen with some Net API calls, such as trying to add the same server twice.
	EPHIDGET_DUPLICATE = 27
	# Bad Credential
	EPHIDGET_BADPASSWORD = 37
	# Network Unavailable
	EPHIDGET_NETUNAVAIL = 45
	# Connection Refused
	EPHIDGET_CONNREF = 35
	# Connection Reset
	EPHIDGET_CONNRESET = 46
	# No route to host
	EPHIDGET_HOSTUNREACH = 48
	# No Such Device
	EPHIDGET_NODEV = 40
	# A Phidget channel object of the wrong channel class was passed into this API call.
	EPHIDGET_WRONGDEVICE = 50
	# Broken Pipe
	EPHIDGET_PIPE = 41
	# Name Resolution Failure
	EPHIDGET_RESOLV = 44
	# The value is unknown. This can happen right after attach, when the value has not yet been recieved from the Phidget. This can also happen if a device has not yet been configured / enabled. Some properties can only be read back after being set.
	EPHIDGET_UNKNOWNVAL = 51
	# This can happen for a number of common reasons. Be sure you are opening the channel before trying to use it. If you are opening the channel, the program may not be waiting for the channel to be attached. If possible use openWaitForAttachment. Otherwise, be sure to check the Attached property of the channel before trying to use it.
	EPHIDGET_NOTATTACHED = 52
	# Invalid or Unexpected Packet
	EPHIDGET_INVALIDPACKET = 53
	# Argument List Too Long
	EPHIDGET_2BIG = 54
	# Bad Version
	EPHIDGET_BADVERSION = 55
	# Channel was closed. This can happen if a channel is closed while openWaitForAttachment is waiting.
	EPHIDGET_CLOSED = 56
	# Device is not configured enough for this API call. Have a look at the must-set properties for this device and make sure to configure them first.
	EPHIDGET_NOTCONFIGURED = 57
	# End of File
	EPHIDGET_EOF = 31
	# Failsafe Triggered on this channel. Close and Re-open the channel to resume operation.
	EPHIDGET_FAILSAFE = 59

	@classmethod
	def getName(self, val):
		if val == self.EPHIDGET_OK:
			return "EPHIDGET_OK"
		if val == self.EPHIDGET_PERM:
			return "EPHIDGET_PERM"
		if val == self.EPHIDGET_NOENT:
			return "EPHIDGET_NOENT"
		if val == self.EPHIDGET_TIMEOUT:
			return "EPHIDGET_TIMEOUT"
		if val == self.EPHIDGET_KEEPALIVE:
			return "EPHIDGET_KEEPALIVE"
		if val == self.EPHIDGET_INTERRUPTED:
			return "EPHIDGET_INTERRUPTED"
		if val == self.EPHIDGET_IO:
			return "EPHIDGET_IO"
		if val == self.EPHIDGET_NOMEMORY:
			return "EPHIDGET_NOMEMORY"
		if val == self.EPHIDGET_ACCESS:
			return "EPHIDGET_ACCESS"
		if val == self.EPHIDGET_FAULT:
			return "EPHIDGET_FAULT"
		if val == self.EPHIDGET_BUSY:
			return "EPHIDGET_BUSY"
		if val == self.EPHIDGET_EXIST:
			return "EPHIDGET_EXIST"
		if val == self.EPHIDGET_NOTDIR:
			return "EPHIDGET_NOTDIR"
		if val == self.EPHIDGET_ISDIR:
			return "EPHIDGET_ISDIR"
		if val == self.EPHIDGET_INVALID:
			return "EPHIDGET_INVALID"
		if val == self.EPHIDGET_NFILE:
			return "EPHIDGET_NFILE"
		if val == self.EPHIDGET_MFILE:
			return "EPHIDGET_MFILE"
		if val == self.EPHIDGET_NOSPC:
			return "EPHIDGET_NOSPC"
		if val == self.EPHIDGET_FBIG:
			return "EPHIDGET_FBIG"
		if val == self.EPHIDGET_ROFS:
			return "EPHIDGET_ROFS"
		if val == self.EPHIDGET_RO:
			return "EPHIDGET_RO"
		if val == self.EPHIDGET_UNSUPPORTED:
			return "EPHIDGET_UNSUPPORTED"
		if val == self.EPHIDGET_INVALIDARG:
			return "EPHIDGET_INVALIDARG"
		if val == self.EPHIDGET_AGAIN:
			return "EPHIDGET_AGAIN"
		if val == self.EPHIDGET_NOTEMPTY:
			return "EPHIDGET_NOTEMPTY"
		if val == self.EPHIDGET_UNEXPECTED:
			return "EPHIDGET_UNEXPECTED"
		if val == self.EPHIDGET_DUPLICATE:
			return "EPHIDGET_DUPLICATE"
		if val == self.EPHIDGET_BADPASSWORD:
			return "EPHIDGET_BADPASSWORD"
		if val == self.EPHIDGET_NETUNAVAIL:
			return "EPHIDGET_NETUNAVAIL"
		if val == self.EPHIDGET_CONNREF:
			return "EPHIDGET_CONNREF"
		if val == self.EPHIDGET_CONNRESET:
			return "EPHIDGET_CONNRESET"
		if val == self.EPHIDGET_HOSTUNREACH:
			return "EPHIDGET_HOSTUNREACH"
		if val == self.EPHIDGET_NODEV:
			return "EPHIDGET_NODEV"
		if val == self.EPHIDGET_WRONGDEVICE:
			return "EPHIDGET_WRONGDEVICE"
		if val == self.EPHIDGET_PIPE:
			return "EPHIDGET_PIPE"
		if val == self.EPHIDGET_RESOLV:
			return "EPHIDGET_RESOLV"
		if val == self.EPHIDGET_UNKNOWNVAL:
			return "EPHIDGET_UNKNOWNVAL"
		if val == self.EPHIDGET_NOTATTACHED:
			return "EPHIDGET_NOTATTACHED"
		if val == self.EPHIDGET_INVALIDPACKET:
			return "EPHIDGET_INVALIDPACKET"
		if val == self.EPHIDGET_2BIG:
			return "EPHIDGET_2BIG"
		if val == self.EPHIDGET_BADVERSION:
			return "EPHIDGET_BADVERSION"
		if val == self.EPHIDGET_CLOSED:
			return "EPHIDGET_CLOSED"
		if val == self.EPHIDGET_NOTCONFIGURED:
			return "EPHIDGET_NOTCONFIGURED"
		if val == self.EPHIDGET_EOF:
			return "EPHIDGET_EOF"
		if val == self.EPHIDGET_FAILSAFE:
			return "EPHIDGET_FAILSAFE"
		return "<invalid enumeration value>"



import sys
import ctypes
class StepperControlMode:
	# Control the motor by setting a target position.
	CONTROL_MODE_STEP = 0
	# Control the motor by selecting a target velocity (sign indicates direction). The motor will rotate continuously in the chosen direction.
	CONTROL_MODE_RUN = 1

	@classmethod
	def getName(self, val):
		if val == self.CONTROL_MODE_STEP:
			return "CONTROL_MODE_STEP"
		if val == self.CONTROL_MODE_RUN:
			return "CONTROL_MODE_RUN"
		return "<invalid enumeration value>"



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.BridgeGain import BridgeGain
from Phidget22.VoltageRatioSensorType import VoltageRatioSensorType
from Phidget22.UnitInfo import UnitInfo
from Phidget22.Unit import Unit
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class VoltageRatioInput(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._SensorChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double, ctypes.POINTER(UnitInfo))
		else:
			self._SensorChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double, ctypes.POINTER(UnitInfo))
		self._SensorChange = None
		self._onSensorChange = None

		if sys.platform == 'win32':
			self._VoltageRatioChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		else:
			self._VoltageRatioChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		self._VoltageRatioChange = None
		self._onVoltageRatioChange = None

		__func = PhidgetSupport.getDll().PhidgetVoltageRatioInput_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localSensorChangeEvent(self, handle, userPtr, sensorValue, sensorUnit):
		if self._SensorChange == None:
			return
		if sensorUnit != None:
			sensorUnit = sensorUnit.contents
			sensorUnit.toPython()
		self._SensorChange(self, sensorValue, sensorUnit)

	def setOnSensorChangeHandler(self, handler):
		if handler == None:
			self._SensorChange = None
			self._onSensorChange = None
		else:
			self._SensorChange = handler
			self._onSensorChange = self._SensorChangeFactory(self._localSensorChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetVoltageRatioInput_setOnSensorChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onSensorChange, None)
		except RuntimeError:
			self._SensorChange = None
			self._onSensorChange = None

	def _localVoltageRatioChangeEvent(self, handle, userPtr, voltageRatio):
		if self._VoltageRatioChange == None:
			return
		self._VoltageRatioChange(self, voltageRatio)

	def setOnVoltageRatioChangeHandler(self, handler):
		if handler == None:
			self._VoltageRatioChange = None
			self._onVoltageRatioChange = None
		else:
			self._VoltageRatioChange = handler
			self._onVoltageRatioChange = self._VoltageRatioChangeFactory(self._localVoltageRatioChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetVoltageRatioInput_setOnVoltageRatioChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onVoltageRatioChange, None)
		except RuntimeError:
			self._VoltageRatioChange = None
			self._onVoltageRatioChange = None

	def getBridgeEnabled(self):
		_BridgeEnabled = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetVoltageRatioInput_getBridgeEnabled
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_BridgeEnabled))

		if result > 0:
			raise PhidgetException(result)

		return _BridgeEnabled.value

	def setBridgeEnabled(self, BridgeEnabled):
		_BridgeEnabled = ctypes.c_int(BridgeEnabled)

		__func = PhidgetSupport.getDll().PhidgetVoltageRatioInput_setBridgeEnabled
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _BridgeEnabled)

		if result > 0:
			raise PhidgetException(result)


	def getBridgeGain(self):
		_BridgeGain = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetVoltageRatioInput_getBridgeGain
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_BridgeGain))

		if result > 0:
			raise PhidgetException(result)

		return _BridgeGain.value

	def setBridgeGain(self, BridgeGain):
		_BridgeGain = ctypes.c_int(BridgeGain)

		__func = PhidgetSupport.getDll().PhidgetVoltageRatioInput_setBridgeGain
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _BridgeGain)

		if result > 0:
			raise PhidgetException(result)


	def getDataInterval(self):
		_DataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetVoltageRatioInput_getDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _DataInterval.value

	def setDataInterval(self, DataInterval):
		_DataInterval = ctypes.c_uint32(DataInterval)

		__func = PhidgetSupport.getDll().PhidgetVoltageRatioInput_setDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataInterval)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataInterval(self):
		_MinDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetVoltageRatioInput_getMinDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataInterval.value

	def getMaxDataInterval(self):
		_MaxDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetVoltageRatioInput_getMaxDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataInterval.value

	def getSensorType(self):
		_SensorType = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetVoltageRatioInput_getSensorType
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_SensorType))

		if result > 0:
			raise PhidgetException(result)

		return _SensorType.value

	def setSensorType(self, SensorType):
		_SensorType = ctypes.c_int(SensorType)

		__func = PhidgetSupport.getDll().PhidgetVoltageRatioInput_setSensorType
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _SensorType)

		if result > 0:
			raise PhidgetException(result)


	def getSensorUnit(self):
		_SensorUnit = UnitInfo()

		__func = PhidgetSupport.getDll().PhidgetVoltageRatioInput_getSensorUnit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_SensorUnit))

		if result > 0:
			raise PhidgetException(result)

		return _SensorUnit.toPython()

	def getSensorValue(self):
		_SensorValue = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetVoltageRatioInput_getSensorValue
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_SensorValue))

		if result > 0:
			raise PhidgetException(result)

		return _SensorValue.value

	def getSensorValueChangeTrigger(self):
		_SensorValueChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetVoltageRatioInput_getSensorValueChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_SensorValueChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _SensorValueChangeTrigger.value

	def setSensorValueChangeTrigger(self, SensorValueChangeTrigger):
		_SensorValueChangeTrigger = ctypes.c_double(SensorValueChangeTrigger)

		__func = PhidgetSupport.getDll().PhidgetVoltageRatioInput_setSensorValueChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _SensorValueChangeTrigger)

		if result > 0:
			raise PhidgetException(result)


	def getVoltageRatio(self):
		_VoltageRatio = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetVoltageRatioInput_getVoltageRatio
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_VoltageRatio))

		if result > 0:
			raise PhidgetException(result)

		return _VoltageRatio.value

	def getMinVoltageRatio(self):
		_MinVoltageRatio = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetVoltageRatioInput_getMinVoltageRatio
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinVoltageRatio))

		if result > 0:
			raise PhidgetException(result)

		return _MinVoltageRatio.value

	def getMaxVoltageRatio(self):
		_MaxVoltageRatio = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetVoltageRatioInput_getMaxVoltageRatio
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxVoltageRatio))

		if result > 0:
			raise PhidgetException(result)

		return _MaxVoltageRatio.value

	def getVoltageRatioChangeTrigger(self):
		_VoltageRatioChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetVoltageRatioInput_getVoltageRatioChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_VoltageRatioChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _VoltageRatioChangeTrigger.value

	def setVoltageRatioChangeTrigger(self, VoltageRatioChangeTrigger):
		_VoltageRatioChangeTrigger = ctypes.c_double(VoltageRatioChangeTrigger)

		__func = PhidgetSupport.getDll().PhidgetVoltageRatioInput_setVoltageRatioChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _VoltageRatioChangeTrigger)

		if result > 0:
			raise PhidgetException(result)


	def getMinVoltageRatioChangeTrigger(self):
		_MinVoltageRatioChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetVoltageRatioInput_getMinVoltageRatioChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinVoltageRatioChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MinVoltageRatioChangeTrigger.value

	def getMaxVoltageRatioChangeTrigger(self):
		_MaxVoltageRatioChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetVoltageRatioInput_getMaxVoltageRatioChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxVoltageRatioChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MaxVoltageRatioChangeTrigger.value



import sys
import ctypes
class VoltageOutputRange:
	# ±10V DC
	VOLTAGE_OUTPUT_RANGE_10V = 1
	# 0-5V DC
	VOLTAGE_OUTPUT_RANGE_5V = 2

	@classmethod
	def getName(self, val):
		if val == self.VOLTAGE_OUTPUT_RANGE_10V:
			return "VOLTAGE_OUTPUT_RANGE_10V"
		if val == self.VOLTAGE_OUTPUT_RANGE_5V:
			return "VOLTAGE_OUTPUT_RANGE_5V"
		return "<invalid enumeration value>"



import sys
import ctypes
class InputMode:
	# For interfacing NPN digital sensors
	INPUT_MODE_NPN = 1
	# For interfacing PNP digital sensors
	INPUT_MODE_PNP = 2

	@classmethod
	def getName(self, val):
		if val == self.INPUT_MODE_NPN:
			return "INPUT_MODE_NPN"
		if val == self.INPUT_MODE_PNP:
			return "INPUT_MODE_PNP"
		return "<invalid enumeration value>"



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class DistanceSensor(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._DistanceChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_uint32)
		else:
			self._DistanceChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_uint32)
		self._DistanceChange = None
		self._onDistanceChange = None

		if sys.platform == 'win32':
			self._SonarReflectionsUpdateFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.POINTER(ctypes.c_uint32), ctypes.POINTER(ctypes.c_uint32), ctypes.c_uint32)
		else:
			self._SonarReflectionsUpdateFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.POINTER(ctypes.c_uint32), ctypes.POINTER(ctypes.c_uint32), ctypes.c_uint32)
		self._SonarReflectionsUpdate = None
		self._onSonarReflectionsUpdate = None

		__func = PhidgetSupport.getDll().PhidgetDistanceSensor_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localDistanceChangeEvent(self, handle, userPtr, distance):
		if self._DistanceChange == None:
			return
		self._DistanceChange(self, distance)

	def setOnDistanceChangeHandler(self, handler):
		if handler == None:
			self._DistanceChange = None
			self._onDistanceChange = None
		else:
			self._DistanceChange = handler
			self._onDistanceChange = self._DistanceChangeFactory(self._localDistanceChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetDistanceSensor_setOnDistanceChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onDistanceChange, None)
		except RuntimeError:
			self._DistanceChange = None
			self._onDistanceChange = None

	def _localSonarReflectionsUpdateEvent(self, handle, userPtr, distances, amplitudes, count):
		if self._SonarReflectionsUpdate == None:
			return
		distances = [distances[i] for i in range(8)]
		amplitudes = [amplitudes[i] for i in range(8)]
		self._SonarReflectionsUpdate(self, distances, amplitudes, count)

	def setOnSonarReflectionsUpdateHandler(self, handler):
		if handler == None:
			self._SonarReflectionsUpdate = None
			self._onSonarReflectionsUpdate = None
		else:
			self._SonarReflectionsUpdate = handler
			self._onSonarReflectionsUpdate = self._SonarReflectionsUpdateFactory(self._localSonarReflectionsUpdateEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetDistanceSensor_setOnSonarReflectionsUpdateHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onSonarReflectionsUpdate, None)
		except RuntimeError:
			self._SonarReflectionsUpdate = None
			self._onSonarReflectionsUpdate = None

	def getDataInterval(self):
		_DataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetDistanceSensor_getDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _DataInterval.value

	def setDataInterval(self, DataInterval):
		_DataInterval = ctypes.c_uint32(DataInterval)

		__func = PhidgetSupport.getDll().PhidgetDistanceSensor_setDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataInterval)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataInterval(self):
		_MinDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetDistanceSensor_getMinDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataInterval.value

	def getMaxDataInterval(self):
		_MaxDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetDistanceSensor_getMaxDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataInterval.value

	def getDistance(self):
		_Distance = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetDistanceSensor_getDistance
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Distance))

		if result > 0:
			raise PhidgetException(result)

		return _Distance.value

	def getMinDistance(self):
		_MinDistance = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetDistanceSensor_getMinDistance
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDistance))

		if result > 0:
			raise PhidgetException(result)

		return _MinDistance.value

	def getMaxDistance(self):
		_MaxDistance = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetDistanceSensor_getMaxDistance
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDistance))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDistance.value

	def getDistanceChangeTrigger(self):
		_DistanceChangeTrigger = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetDistanceSensor_getDistanceChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DistanceChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _DistanceChangeTrigger.value

	def setDistanceChangeTrigger(self, DistanceChangeTrigger):
		_DistanceChangeTrigger = ctypes.c_uint32(DistanceChangeTrigger)

		__func = PhidgetSupport.getDll().PhidgetDistanceSensor_setDistanceChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DistanceChangeTrigger)

		if result > 0:
			raise PhidgetException(result)


	def getMinDistanceChangeTrigger(self):
		_MinDistanceChangeTrigger = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetDistanceSensor_getMinDistanceChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDistanceChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MinDistanceChangeTrigger.value

	def getMaxDistanceChangeTrigger(self):
		_MaxDistanceChangeTrigger = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetDistanceSensor_getMaxDistanceChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDistanceChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDistanceChangeTrigger.value

	def getSonarQuietMode(self):
		_SonarQuietMode = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetDistanceSensor_getSonarQuietMode
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_SonarQuietMode))

		if result > 0:
			raise PhidgetException(result)

		return _SonarQuietMode.value

	def setSonarQuietMode(self, SonarQuietMode):
		_SonarQuietMode = ctypes.c_int(SonarQuietMode)

		__func = PhidgetSupport.getDll().PhidgetDistanceSensor_setSonarQuietMode
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _SonarQuietMode)

		if result > 0:
			raise PhidgetException(result)


	def getSonarReflections(self):
		_distances = (ctypes.c_uint32 * 8)()
		_amplitudes = (ctypes.c_uint32 * 8)()
		_count = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetDistanceSensor_getSonarReflections
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_distances), ctypes.byref(_amplitudes), ctypes.byref(_count))

		if result > 0:
			raise PhidgetException(result)

		return list(_distances), list(_amplitudes), _count.value



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class Magnetometer(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._MagneticFieldChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.POINTER(ctypes.c_double), ctypes.c_double)
		else:
			self._MagneticFieldChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.POINTER(ctypes.c_double), ctypes.c_double)
		self._MagneticFieldChange = None
		self._onMagneticFieldChange = None

		__func = PhidgetSupport.getDll().PhidgetMagnetometer_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localMagneticFieldChangeEvent(self, handle, userPtr, magneticField, timestamp):
		if self._MagneticFieldChange == None:
			return
		magneticField = [magneticField[i] for i in range(3)]
		self._MagneticFieldChange(self, magneticField, timestamp)

	def setOnMagneticFieldChangeHandler(self, handler):
		if handler == None:
			self._MagneticFieldChange = None
			self._onMagneticFieldChange = None
		else:
			self._MagneticFieldChange = handler
			self._onMagneticFieldChange = self._MagneticFieldChangeFactory(self._localMagneticFieldChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetMagnetometer_setOnMagneticFieldChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onMagneticFieldChange, None)
		except RuntimeError:
			self._MagneticFieldChange = None
			self._onMagneticFieldChange = None

	def getAxisCount(self):
		_AxisCount = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetMagnetometer_getAxisCount
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_AxisCount))

		if result > 0:
			raise PhidgetException(result)

		return _AxisCount.value

	def setCorrectionParameters(self, magneticField, offset0, offset1, offset2, gain0, gain1, gain2, T0, T1, T2, T3, T4, T5):
		_magneticField = ctypes.c_double(magneticField)
		_offset0 = ctypes.c_double(offset0)
		_offset1 = ctypes.c_double(offset1)
		_offset2 = ctypes.c_double(offset2)
		_gain0 = ctypes.c_double(gain0)
		_gain1 = ctypes.c_double(gain1)
		_gain2 = ctypes.c_double(gain2)
		_T0 = ctypes.c_double(T0)
		_T1 = ctypes.c_double(T1)
		_T2 = ctypes.c_double(T2)
		_T3 = ctypes.c_double(T3)
		_T4 = ctypes.c_double(T4)
		_T5 = ctypes.c_double(T5)

		__func = PhidgetSupport.getDll().PhidgetMagnetometer_setCorrectionParameters
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _magneticField, _offset0, _offset1, _offset2, _gain0, _gain1, _gain2, _T0, _T1, _T2, _T3, _T4, _T5)

		if result > 0:
			raise PhidgetException(result)


	def getDataInterval(self):
		_DataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetMagnetometer_getDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _DataInterval.value

	def setDataInterval(self, DataInterval):
		_DataInterval = ctypes.c_uint32(DataInterval)

		__func = PhidgetSupport.getDll().PhidgetMagnetometer_setDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataInterval)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataInterval(self):
		_MinDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetMagnetometer_getMinDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataInterval.value

	def getMaxDataInterval(self):
		_MaxDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetMagnetometer_getMaxDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataInterval.value

	def getHeatingEnabled(self):
		_HeatingEnabled = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetMagnetometer_getHeatingEnabled
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_HeatingEnabled))

		if result > 0:
			raise PhidgetException(result)

		return _HeatingEnabled.value

	def setHeatingEnabled(self, HeatingEnabled):
		_HeatingEnabled = ctypes.c_int(HeatingEnabled)

		__func = PhidgetSupport.getDll().PhidgetMagnetometer_setHeatingEnabled
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _HeatingEnabled)

		if result > 0:
			raise PhidgetException(result)


	def getMagneticField(self):
		_MagneticField = (ctypes.c_double * 3)()

		__func = PhidgetSupport.getDll().PhidgetMagnetometer_getMagneticField
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MagneticField))

		if result > 0:
			raise PhidgetException(result)

		return list(_MagneticField)

	def getMinMagneticField(self):
		_MinMagneticField = (ctypes.c_double * 3)()

		__func = PhidgetSupport.getDll().PhidgetMagnetometer_getMinMagneticField
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinMagneticField))

		if result > 0:
			raise PhidgetException(result)

		return list(_MinMagneticField)

	def getMaxMagneticField(self):
		_MaxMagneticField = (ctypes.c_double * 3)()

		__func = PhidgetSupport.getDll().PhidgetMagnetometer_getMaxMagneticField
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxMagneticField))

		if result > 0:
			raise PhidgetException(result)

		return list(_MaxMagneticField)

	def getMagneticFieldChangeTrigger(self):
		_MagneticFieldChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMagnetometer_getMagneticFieldChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MagneticFieldChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MagneticFieldChangeTrigger.value

	def setMagneticFieldChangeTrigger(self, MagneticFieldChangeTrigger):
		_MagneticFieldChangeTrigger = ctypes.c_double(MagneticFieldChangeTrigger)

		__func = PhidgetSupport.getDll().PhidgetMagnetometer_setMagneticFieldChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _MagneticFieldChangeTrigger)

		if result > 0:
			raise PhidgetException(result)


	def getMinMagneticFieldChangeTrigger(self):
		_MinMagneticFieldChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMagnetometer_getMinMagneticFieldChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinMagneticFieldChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MinMagneticFieldChangeTrigger.value

	def getMaxMagneticFieldChangeTrigger(self):
		_MaxMagneticFieldChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMagnetometer_getMaxMagneticFieldChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxMagneticFieldChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MaxMagneticFieldChangeTrigger.value

	def resetCorrectionParameters(self):
		__func = PhidgetSupport.getDll().PhidgetMagnetometer_resetCorrectionParameters
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)


	def saveCorrectionParameters(self):
		__func = PhidgetSupport.getDll().PhidgetMagnetometer_saveCorrectionParameters
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)


	def getTimestamp(self):
		_Timestamp = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetMagnetometer_getTimestamp
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Timestamp))

		if result > 0:
			raise PhidgetException(result)

		return _Timestamp.value



import sys
import ctypes
class HandshakeMode:
	# RTS is never set, and CTS is ignored.
	HANDSHAKE_MODE_NONE = 1
	# RTS Pin requests to transmit data. CTS input confirms we can send data.
	HANDSHAKE_MODE_REQUEST_TO_SEND = 2
	# RTS signals this device can receive data. CTS confirms we can send data.
	HANDSHAKE_MODE_READY_TO_RECEIVE = 3

	@classmethod
	def getName(self, val):
		if val == self.HANDSHAKE_MODE_NONE:
			return "HANDSHAKE_MODE_NONE"
		if val == self.HANDSHAKE_MODE_REQUEST_TO_SEND:
			return "HANDSHAKE_MODE_REQUEST_TO_SEND"
		if val == self.HANDSHAKE_MODE_READY_TO_RECEIVE:
			return "HANDSHAKE_MODE_READY_TO_RECEIVE"
		return "<invalid enumeration value>"



import sys
import ctypes
class FanMode:
	# Turns the fan off.
	FAN_MODE_OFF = 1
	# Turns the fan on.
	FAN_MODE_ON = 2
	# The fan will be automatically controlled based on temperature.
	FAN_MODE_AUTO = 3

	@classmethod
	def getName(self, val):
		if val == self.FAN_MODE_OFF:
			return "FAN_MODE_OFF"
		if val == self.FAN_MODE_ON:
			return "FAN_MODE_ON"
		if val == self.FAN_MODE_AUTO:
			return "FAN_MODE_AUTO"
		return "<invalid enumeration value>"



import sys
import ctypes
class Parity:
	# No Parity Bit
	PARITY_MODE_NONE = 1
	# Even Parity
	PARITY_MODE_EVEN = 2
	# Odd Parity
	PARITY_MODE_ODD = 3

	@classmethod
	def getName(self, val):
		if val == self.PARITY_MODE_NONE:
			return "PARITY_MODE_NONE"
		if val == self.PARITY_MODE_EVEN:
			return "PARITY_MODE_EVEN"
		if val == self.PARITY_MODE_ODD:
			return "PARITY_MODE_ODD"
		return "<invalid enumeration value>"



import sys
import ctypes
class ChannelClass:
	# Accelerometer channel
	PHIDCHCLASS_ACCELEROMETER = 1
	# Current input channel
	PHIDCHCLASS_CURRENTINPUT = 2
	# DC motor channel
	PHIDCHCLASS_DCMOTOR = 4
	# Digital input channel
	PHIDCHCLASS_DIGITALINPUT = 5
	# Digital output channel
	PHIDCHCLASS_DIGITALOUTPUT = 6
	# Distance sensor channel
	PHIDCHCLASS_DISTANCESENSOR = 7
	# Encoder channel
	PHIDCHCLASS_ENCODER = 8
	# Frequency counter channel
	PHIDCHCLASS_FREQUENCYCOUNTER = 9
	# GPS channel
	PHIDCHCLASS_GPS = 10
	# LCD channel
	PHIDCHCLASS_LCD = 11
	# Gyroscope channel
	PHIDCHCLASS_GYROSCOPE = 12
	# VINT Hub channel
	PHIDCHCLASS_HUB = 13
	# Capacitive Touch channel
	PHIDCHCLASS_CAPACITIVETOUCH = 14
	# Humidity sensor channel
	PHIDCHCLASS_HUMIDITYSENSOR = 15
	# IR channel
	PHIDCHCLASS_IR = 16
	# Light sensor channel
	PHIDCHCLASS_LIGHTSENSOR = 17
	# Magnetometer channel
	PHIDCHCLASS_MAGNETOMETER = 18
	# pH sensor channel
	PHIDCHCLASS_PHSENSOR = 37
	# Power guard channel
	PHIDCHCLASS_POWERGUARD = 20
	# Pressure sensor channel
	PHIDCHCLASS_PRESSURESENSOR = 21
	# RC Servo channel
	PHIDCHCLASS_RCSERVO = 22
	# Resistance input channel
	PHIDCHCLASS_RESISTANCEINPUT = 23
	# RFID channel
	PHIDCHCLASS_RFID = 24
	# Sound sensor channel
	PHIDCHCLASS_SOUNDSENSOR = 25
	# Spatial channel
	PHIDCHCLASS_SPATIAL = 26
	# Stepper channel
	PHIDCHCLASS_STEPPER = 27
	# Temperature sensor channel
	PHIDCHCLASS_TEMPERATURESENSOR = 28
	# Voltage input channel
	PHIDCHCLASS_VOLTAGEINPUT = 29
	# Voltage output channel
	PHIDCHCLASS_VOLTAGEOUTPUT = 30
	# Voltage ratio input channel
	PHIDCHCLASS_VOLTAGERATIOINPUT = 31
	# Motor position control channel.
	PHIDCHCLASS_MOTORPOSITIONCONTROLLER = 34
	# BLDC motor channel
	PHIDCHCLASS_BLDCMOTOR = 35
	# Dictionary
	PHIDCHCLASS_DICTIONARY = 36
	# Current output channel
	PHIDCHCLASS_CURRENTOUTPUT = 38

	@classmethod
	def getName(self, val):
		if val == self.PHIDCHCLASS_ACCELEROMETER:
			return "PHIDCHCLASS_ACCELEROMETER"
		if val == self.PHIDCHCLASS_CURRENTINPUT:
			return "PHIDCHCLASS_CURRENTINPUT"
		if val == self.PHIDCHCLASS_DCMOTOR:
			return "PHIDCHCLASS_DCMOTOR"
		if val == self.PHIDCHCLASS_DIGITALINPUT:
			return "PHIDCHCLASS_DIGITALINPUT"
		if val == self.PHIDCHCLASS_DIGITALOUTPUT:
			return "PHIDCHCLASS_DIGITALOUTPUT"
		if val == self.PHIDCHCLASS_DISTANCESENSOR:
			return "PHIDCHCLASS_DISTANCESENSOR"
		if val == self.PHIDCHCLASS_ENCODER:
			return "PHIDCHCLASS_ENCODER"
		if val == self.PHIDCHCLASS_FREQUENCYCOUNTER:
			return "PHIDCHCLASS_FREQUENCYCOUNTER"
		if val == self.PHIDCHCLASS_GPS:
			return "PHIDCHCLASS_GPS"
		if val == self.PHIDCHCLASS_LCD:
			return "PHIDCHCLASS_LCD"
		if val == self.PHIDCHCLASS_GYROSCOPE:
			return "PHIDCHCLASS_GYROSCOPE"
		if val == self.PHIDCHCLASS_HUB:
			return "PHIDCHCLASS_HUB"
		if val == self.PHIDCHCLASS_CAPACITIVETOUCH:
			return "PHIDCHCLASS_CAPACITIVETOUCH"
		if val == self.PHIDCHCLASS_HUMIDITYSENSOR:
			return "PHIDCHCLASS_HUMIDITYSENSOR"
		if val == self.PHIDCHCLASS_IR:
			return "PHIDCHCLASS_IR"
		if val == self.PHIDCHCLASS_LIGHTSENSOR:
			return "PHIDCHCLASS_LIGHTSENSOR"
		if val == self.PHIDCHCLASS_MAGNETOMETER:
			return "PHIDCHCLASS_MAGNETOMETER"
		if val == self.PHIDCHCLASS_PHSENSOR:
			return "PHIDCHCLASS_PHSENSOR"
		if val == self.PHIDCHCLASS_POWERGUARD:
			return "PHIDCHCLASS_POWERGUARD"
		if val == self.PHIDCHCLASS_PRESSURESENSOR:
			return "PHIDCHCLASS_PRESSURESENSOR"
		if val == self.PHIDCHCLASS_RCSERVO:
			return "PHIDCHCLASS_RCSERVO"
		if val == self.PHIDCHCLASS_RESISTANCEINPUT:
			return "PHIDCHCLASS_RESISTANCEINPUT"
		if val == self.PHIDCHCLASS_RFID:
			return "PHIDCHCLASS_RFID"
		if val == self.PHIDCHCLASS_SOUNDSENSOR:
			return "PHIDCHCLASS_SOUNDSENSOR"
		if val == self.PHIDCHCLASS_SPATIAL:
			return "PHIDCHCLASS_SPATIAL"
		if val == self.PHIDCHCLASS_STEPPER:
			return "PHIDCHCLASS_STEPPER"
		if val == self.PHIDCHCLASS_TEMPERATURESENSOR:
			return "PHIDCHCLASS_TEMPERATURESENSOR"
		if val == self.PHIDCHCLASS_VOLTAGEINPUT:
			return "PHIDCHCLASS_VOLTAGEINPUT"
		if val == self.PHIDCHCLASS_VOLTAGEOUTPUT:
			return "PHIDCHCLASS_VOLTAGEOUTPUT"
		if val == self.PHIDCHCLASS_VOLTAGERATIOINPUT:
			return "PHIDCHCLASS_VOLTAGERATIOINPUT"
		if val == self.PHIDCHCLASS_MOTORPOSITIONCONTROLLER:
			return "PHIDCHCLASS_MOTORPOSITIONCONTROLLER"
		if val == self.PHIDCHCLASS_BLDCMOTOR:
			return "PHIDCHCLASS_BLDCMOTOR"
		if val == self.PHIDCHCLASS_DICTIONARY:
			return "PHIDCHCLASS_DICTIONARY"
		if val == self.PHIDCHCLASS_CURRENTOUTPUT:
			return "PHIDCHCLASS_CURRENTOUTPUT"
		return "<invalid enumeration value>"



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class Gyroscope(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._AngularRateUpdateFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.POINTER(ctypes.c_double), ctypes.c_double)
		else:
			self._AngularRateUpdateFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.POINTER(ctypes.c_double), ctypes.c_double)
		self._AngularRateUpdate = None
		self._onAngularRateUpdate = None

		__func = PhidgetSupport.getDll().PhidgetGyroscope_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localAngularRateUpdateEvent(self, handle, userPtr, angularRate, timestamp):
		if self._AngularRateUpdate == None:
			return
		angularRate = [angularRate[i] for i in range(3)]
		self._AngularRateUpdate(self, angularRate, timestamp)

	def setOnAngularRateUpdateHandler(self, handler):
		if handler == None:
			self._AngularRateUpdate = None
			self._onAngularRateUpdate = None
		else:
			self._AngularRateUpdate = handler
			self._onAngularRateUpdate = self._AngularRateUpdateFactory(self._localAngularRateUpdateEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetGyroscope_setOnAngularRateUpdateHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onAngularRateUpdate, None)
		except RuntimeError:
			self._AngularRateUpdate = None
			self._onAngularRateUpdate = None

	def getAngularRate(self):
		_AngularRate = (ctypes.c_double * 3)()

		__func = PhidgetSupport.getDll().PhidgetGyroscope_getAngularRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_AngularRate))

		if result > 0:
			raise PhidgetException(result)

		return list(_AngularRate)

	def getMinAngularRate(self):
		_MinAngularRate = (ctypes.c_double * 3)()

		__func = PhidgetSupport.getDll().PhidgetGyroscope_getMinAngularRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinAngularRate))

		if result > 0:
			raise PhidgetException(result)

		return list(_MinAngularRate)

	def getMaxAngularRate(self):
		_MaxAngularRate = (ctypes.c_double * 3)()

		__func = PhidgetSupport.getDll().PhidgetGyroscope_getMaxAngularRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxAngularRate))

		if result > 0:
			raise PhidgetException(result)

		return list(_MaxAngularRate)

	def getAxisCount(self):
		_AxisCount = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetGyroscope_getAxisCount
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_AxisCount))

		if result > 0:
			raise PhidgetException(result)

		return _AxisCount.value

	def getDataInterval(self):
		_DataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetGyroscope_getDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _DataInterval.value

	def setDataInterval(self, DataInterval):
		_DataInterval = ctypes.c_uint32(DataInterval)

		__func = PhidgetSupport.getDll().PhidgetGyroscope_setDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataInterval)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataInterval(self):
		_MinDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetGyroscope_getMinDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataInterval.value

	def getMaxDataInterval(self):
		_MaxDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetGyroscope_getMaxDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataInterval.value

	def getHeatingEnabled(self):
		_HeatingEnabled = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetGyroscope_getHeatingEnabled
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_HeatingEnabled))

		if result > 0:
			raise PhidgetException(result)

		return _HeatingEnabled.value

	def setHeatingEnabled(self, HeatingEnabled):
		_HeatingEnabled = ctypes.c_int(HeatingEnabled)

		__func = PhidgetSupport.getDll().PhidgetGyroscope_setHeatingEnabled
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _HeatingEnabled)

		if result > 0:
			raise PhidgetException(result)


	def getTimestamp(self):
		_Timestamp = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetGyroscope_getTimestamp
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Timestamp))

		if result > 0:
			raise PhidgetException(result)

		return _Timestamp.value

	def zero(self):
		__func = PhidgetSupport.getDll().PhidgetGyroscope_zero
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)




import sys
import ctypes
class RFIDProtocol:
	# EM4100
	PROTOCOL_EM4100 = 1
	# ISO11785 FDX B
	PROTOCOL_ISO11785_FDX_B = 2
	# PhidgetTAG
	PROTOCOL_PHIDGETS = 3

	@classmethod
	def getName(self, val):
		if val == self.PROTOCOL_EM4100:
			return "PROTOCOL_EM4100"
		if val == self.PROTOCOL_ISO11785_FDX_B:
			return "PROTOCOL_ISO11785_FDX_B"
		if val == self.PROTOCOL_PHIDGETS:
			return "PROTOCOL_PHIDGETS"
		return "<invalid enumeration value>"



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(name="Phidget22",
    version='1.9.20220203',
    author="Phidgets Inc",
    author_email="support@phidgets.com",
    description="Phidget22 Python wrapper library",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="http://www.phidgets.com",
    packages=setuptools.find_packages(),
    license='MIT',
    classifiers=[
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)



import sys
import ctypes
class LogLevel:
	# Critical
	PHIDGET_LOG_CRITICAL = 1
	# Error
	PHIDGET_LOG_ERROR = 2
	# Warning
	PHIDGET_LOG_WARNING = 3
	# Info
	PHIDGET_LOG_INFO = 4
	# Debug
	PHIDGET_LOG_DEBUG = 5
	# Verbose
	PHIDGET_LOG_VERBOSE = 6

	@classmethod
	def getName(self, val):
		if val == self.PHIDGET_LOG_CRITICAL:
			return "PHIDGET_LOG_CRITICAL"
		if val == self.PHIDGET_LOG_ERROR:
			return "PHIDGET_LOG_ERROR"
		if val == self.PHIDGET_LOG_WARNING:
			return "PHIDGET_LOG_WARNING"
		if val == self.PHIDGET_LOG_INFO:
			return "PHIDGET_LOG_INFO"
		if val == self.PHIDGET_LOG_DEBUG:
			return "PHIDGET_LOG_DEBUG"
		if val == self.PHIDGET_LOG_VERBOSE:
			return "PHIDGET_LOG_VERBOSE"
		return "<invalid enumeration value>"



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.RTDWireSetup import RTDWireSetup
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class ResistanceInput(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._ResistanceChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		else:
			self._ResistanceChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		self._ResistanceChange = None
		self._onResistanceChange = None

		__func = PhidgetSupport.getDll().PhidgetResistanceInput_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localResistanceChangeEvent(self, handle, userPtr, resistance):
		if self._ResistanceChange == None:
			return
		self._ResistanceChange(self, resistance)

	def setOnResistanceChangeHandler(self, handler):
		if handler == None:
			self._ResistanceChange = None
			self._onResistanceChange = None
		else:
			self._ResistanceChange = handler
			self._onResistanceChange = self._ResistanceChangeFactory(self._localResistanceChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetResistanceInput_setOnResistanceChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onResistanceChange, None)
		except RuntimeError:
			self._ResistanceChange = None
			self._onResistanceChange = None

	def getDataInterval(self):
		_DataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetResistanceInput_getDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _DataInterval.value

	def setDataInterval(self, DataInterval):
		_DataInterval = ctypes.c_uint32(DataInterval)

		__func = PhidgetSupport.getDll().PhidgetResistanceInput_setDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataInterval)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataInterval(self):
		_MinDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetResistanceInput_getMinDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataInterval.value

	def getMaxDataInterval(self):
		_MaxDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetResistanceInput_getMaxDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataInterval.value

	def getResistance(self):
		_Resistance = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetResistanceInput_getResistance
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Resistance))

		if result > 0:
			raise PhidgetException(result)

		return _Resistance.value

	def getMinResistance(self):
		_MinResistance = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetResistanceInput_getMinResistance
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinResistance))

		if result > 0:
			raise PhidgetException(result)

		return _MinResistance.value

	def getMaxResistance(self):
		_MaxResistance = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetResistanceInput_getMaxResistance
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxResistance))

		if result > 0:
			raise PhidgetException(result)

		return _MaxResistance.value

	def getResistanceChangeTrigger(self):
		_ResistanceChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetResistanceInput_getResistanceChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_ResistanceChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _ResistanceChangeTrigger.value

	def setResistanceChangeTrigger(self, ResistanceChangeTrigger):
		_ResistanceChangeTrigger = ctypes.c_double(ResistanceChangeTrigger)

		__func = PhidgetSupport.getDll().PhidgetResistanceInput_setResistanceChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _ResistanceChangeTrigger)

		if result > 0:
			raise PhidgetException(result)


	def getMinResistanceChangeTrigger(self):
		_MinResistanceChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetResistanceInput_getMinResistanceChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinResistanceChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MinResistanceChangeTrigger.value

	def getMaxResistanceChangeTrigger(self):
		_MaxResistanceChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetResistanceInput_getMaxResistanceChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxResistanceChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MaxResistanceChangeTrigger.value

	def getRTDWireSetup(self):
		_RTDWireSetup = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetResistanceInput_getRTDWireSetup
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_RTDWireSetup))

		if result > 0:
			raise PhidgetException(result)

		return _RTDWireSetup.value

	def setRTDWireSetup(self, RTDWireSetup):
		_RTDWireSetup = ctypes.c_int(RTDWireSetup)

		__func = PhidgetSupport.getDll().PhidgetResistanceInput_setRTDWireSetup
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _RTDWireSetup)

		if result > 0:
			raise PhidgetException(result)

